//--------------------------------------------------------------
// File     : stm32_ub_sram.h
//--------------------------------------------------------------

//--------------------------------------------------------------
#ifndef __STM32F4_UB_SRAM_H
#define __STM32F4_UB_SRAM_H


//--------------------------------------------------------------
// Includes
//--------------------------------------------------------------
#include "stm32f4xx.h"
#include "stm32f4xx_gpio.h"
#include "stm32f4xx_rcc.h"
#include "stm32f4xx_fsmc.h"



//--------------------------------------------------------------
// Adressen vom FSMC um auf das SRAM zuzugreifen
// Bank   = Bank-1 / PSRAM-1        => BaseAdr 0x60000000
// (siehe Seite 1316+1317 vom Referenz Manual)
//--------------------------------------------------------------
#define SRAM_ADR   ((uint32_t)0x60000000)  // Adresse vom RAM



//--------------------------------------------------------------
// Defines vom SRAM
//--------------------------------------------------------------
#define  SRAM_FSMC_AST  7 // AdressSetupTime  (AST >= 7) [0..15]
#define  SRAM_FSMC_DST  3 // DataSetupTime    (DST >= 3) [0..255]
#define  SRAM_FSMC_AHT  4 // AdressHoldTime   (AHT >= 4) [0..15]

#define  SRAM_MAX_ADR     0x3FFFF  // max = 256k => *16bit = 4Mbit



//--------------------------------------------------------------
// Globale Funktionen
//--------------------------------------------------------------
ErrorStatus UB_SRAM_Init(void);
void UB_SRAM_Write(uint32_t adr, uint16_t wert);
uint16_t UB_SRAM_Read(uint32_t adr);


//--------------------------------------------------------------
#endif // __STM32F4_UB_SRAM_H
